summaryrefslogtreecommitdiffstats
path: root/chromeos/dbus/debug_daemon_client.h
diff options
context:
space:
mode:
authorzelidrag@chromium.org <zelidrag@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-07-23 22:29:29 +0000
committerzelidrag@chromium.org <zelidrag@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-07-23 22:29:29 +0000
commitcc5ff9853cbda52ac6679cce3a4eb7af6d685be1 (patch)
tree4842f218d0da2448aa245e18136c668d8ae8813a /chromeos/dbus/debug_daemon_client.h
parentfb83cf1a4226405d3000f82f334c361ba507b852 (diff)
downloadchromium_src-cc5ff9853cbda52ac6679cce3a4eb7af6d685be1.zip
chromium_src-cc5ff9853cbda52ac6679cce3a4eb7af6d685be1.tar.gz
chromium_src-cc5ff9853cbda52ac6679cce3a4eb7af6d685be1.tar.bz2
Added additional methods for chrome.logPrivate:
chrome.logPrivate.dumpLogs(function(fileEntry) {...}); - dumps all system logs as |fileEntry| (a .tgz file) chrome.logPrivate.startEventRecorder(type, function(){}); chrome.logPrivate.stopEventRecorder(type, function(){}); - start/stop additional log collection for dumps generated with chrome.logPrivate.dumpLogs(). TEST=LogPrivateApiTest.* BUG=385289 Review URL: https://codereview.chromium.org/329853010 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@285065 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chromeos/dbus/debug_daemon_client.h')
-rw-r--r--chromeos/dbus/debug_daemon_client.h8
1 files changed, 5 insertions, 3 deletions
diff --git a/chromeos/dbus/debug_daemon_client.h b/chromeos/dbus/debug_daemon_client.h
index d1ed8b8..30cc5a4 100644
--- a/chromeos/dbus/debug_daemon_client.h
+++ b/chromeos/dbus/debug_daemon_client.h
@@ -29,9 +29,11 @@ class CHROMEOS_EXPORT DebugDaemonClient : public DBusClient {
typedef base::Callback<void(bool succeeded)> GetDebugLogsCallback;
// Requests to store debug logs into |file| and calls |callback|
- // when completed. Debug logs will be stored in the .tgz format.
- virtual void GetDebugLogs(base::File file,
- const GetDebugLogsCallback& callback) = 0;
+ // when completed. Debug logs will be stored in the .tgz if
+ // |is_compressed| is true, otherwise in logs will be stored in .tar format.
+ virtual void DumpDebugLogs(bool is_compressed,
+ base::File file,
+ const GetDebugLogsCallback& callback) = 0;
// Called once SetDebugMode() is complete. Takes one parameter:
// - succeeded: debug mode was changed successfully.